Mfm class
- Inheritance
Constructors
-
Mfm({Key? key, String? mfmText, List<
MfmNode> ? mfmNode, EmojiBuilder? emojiBuilder, UnicodeEmojiBuilder? unicodeEmojiBuilder, CodeBlockBuilder? codeBlockBuilder, InlineCodeBuilder? inlineCodeBuilder, SmallStyleBuilder? smallStyleBuilder, QuoteBuilder? quoteBuilder, SearchBuilder? searchBuilder, UnixTimeBuilder? unixTimeBuilder, double lineHeight = 1.35, TextStyle? style, TextStyle boldStyle = const TextStyle(fontWeight: FontWeight.bold), TextStyle? linkStyle, TextStyle? mentionStyle, TextStyle? hashtagStyle, TextStyle? serifStyle, TextStyle? monospaceStyle, TextStyle? cursiveStyle, TextStyle? fantasyStyle, MentionTapCallBack? mentionTap, HashtagCallback? hashtagTap, LinkTapCallback? linkTap, SearchTapCallback? searchTap, bool isNyaize = false, List<InlineSpan> prefixSpan = const [], List<InlineSpan> suffixSpan = const [], bool isUseAnimation = true, Color defaultBorderColor = Colors.purpleAccent, TextOverflow? overflow, int? maxLines}) -
Markup Language for Misskey Sample.
const
Properties
- boldStyle → TextStyle
-
bold (such as
<b>**) element stylefinal - child → Widget
-
The widget below this widget in the tree.
finalinherited
- codeBlockBuilder → CodeBlockBuilder?
-
code block builder
final
- cursiveStyle → TextStyle?
-
$[font.cursive ]element stylefinal - defaultBorderColor → Color
-
final
- emojiBuilder → EmojiBuilder?
-
builder for emoji.
final
- fantasyStyle → TextStyle?
-
$[font.fantasy ]elemen stylefinal - hashCode → int
-
The hash code for this object.
no setterinherited
- hashtagStyle → TextStyle?
-
hashtag element style
final
- hashtagTap → HashtagCallback?
-
callback when tap hashtag.
final
- inlineCodeBuilder → EmojiBuilder?
-
inline code builder.
final
- isNyaize → bool
-
apply text nyaize
final
- isUseAnimation → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineHeight → double
-
line height.
final
- linkStyle → TextStyle?
-
link element style
final
- linkTap → HashtagCallback?
-
callback when tap link, url.
final
- maxLines → int?
-
See Text.maxLines
final
- mentionStyle → TextStyle?
-
mention element style
final
- mentionTap → MentionTapCallBack?
-
callback when tap mention.
final
-
mfmNode
→ List<
MfmNode> ? -
parsed mfm text.
final
- mfmText → String?
-
mfm text. must be non-null mfmText or mfmNode.
final
- monospaceStyle → TextStyle?
-
$[font.monospace ]element stylefinal - overflow → TextOverflow?
-
See Text.overflow
final
-
prefixSpan
→ List<
InlineSpan> -
add prefix span
final
- quoteBuilder → QuoteBuilder?
-
quote block builder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchBuilder → SearchBuilder?
-
search block builder
final
- searchTap → HashtagCallback?
-
callback when tap
Seachfinal - serifStyle → TextStyle?
-
$[font.serif ]element stylefinal - smallStyleBuilder → SmallStyleBuilder?
-
<small>...</small>style builder. argumentsstyle.fontSizewill be provide currently font size. font size will be changed relativity, such as$[x2 <small>...</small>]syntax.final - style → TextStyle?
-
base text style.
final
-
suffixSpan
→ List<
InlineSpan> -
add suffix span
final
- unicodeEmojiBuilder → UnicodeEmojiBuilder?
-
builder for unicode emoji.
final
- unixTimeBuilder → UnixTimeBuilder?
-
$[unixtime builder
final
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant Mfm oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → Mfm - provides root MFM Widget